@@ -1,5 +1,5 @@
 package Bio::ToolBox::Data;
-our $VERSION = 1.14;
+our $VERSION = 1.15;
 
 =head1 NAME
 
@@ -140,9 +140,13 @@ Provide the name of the database from which to collect the
 features. It may be a short name, whereupon it is checked in 
 the Bio::ToolBox configuration file C<.biotoolbox.cfg> for 
 connection information. Alternatively, a path to a database 
-file or directory may be given. If you already have an opened 
-Bio::DB::SeqFeature::Store database object, you can simply 
-pass that. See Bio::ToolBox::db_helper for more information.
+file or directory may be given. 
+
+If you already have an opened Bio::DB::SeqFeature::Store database 
+object, you can simply pass that. See Bio::ToolBox::db_helper for 
+more information. However, this in general should be discouraged, 
+since the name of the database will not be properly recorded when 
+saving to file.
 
 =item win =E<gt> $integer
 
@@ -332,8 +336,17 @@ the beginning of the file.
 
 =item metadata($index, $key, $new_value)
 
-Returns or sets the metadata value for a specific key for a 
-specific column index.
+Returns or sets the metadata value for a specific $key for a 
+specific column $index.
+
+This may also be used to add a new metadata key. Simply provide 
+the name of a new $key that is not present
+
+=item delete_metadata($index, $key);
+
+Deletes a column-specific metadata $key and value for a specific 
+column $index. If a $key is not provided, then all metadata keys 
+for that index will be deleted.
 
 =item find_column($name)
 
@@ -546,6 +559,7 @@ For example, to fork the program into four concurrent processes.
 		$pm->start and next;
 		### in child
 		$Data->splice_data($i, 4);
+		$db = $Data->open_database; # a clone-safe new db object
 		# do something with this portion
 		$Data->save('filename' => "file#$i");
 		$pm->finish;
@@ -556,9 +570,16 @@ There is no convenient method for merging the modified contents of the
 table from each child process back into the original Data table, as 
 each child is essentially isolated from the parent. The Parallel::ForkManager 
 documentation recommends going through a disk file intermediate. See the 
-accompanying BioToolBox script join_data_file.pl for concatenating Data 
+accompanying BioToolBox script F<join_data_file.pl> for concatenating Data 
 table files together.
 
+Remember that if you fork your script into child processes, any database 
+connections must be re-opened; they are typically not clone safe. If you 
+have an existing database connection by using the open_database() method, 
+it should be automatically re-opened for you when you use the splice_data() 
+method, but you will need to call open_database() again in the child 
+process to obtain the new database object.
+
 =item convert_gff(%options)
 
 This method will irreversibly convert the Data table into a GFF format.
@@ -858,7 +879,13 @@ sub verify {
 
 sub splice_data {
 	my $self = shift;
-	return splice_data_structure($self, @_);
+	splice_data_structure($self, @_);
+	if ($self->{db} and exists $self->{db_connection}) {
+		# re-open a new un-cached database connection
+		my $db = open_db_connection($self->{db}, 1);
+		$self->{db_connection} = $db if $db;
+	}
+	return 1;
 }
 
 sub convert_gff {
@@ -894,7 +921,8 @@ sub database {
 	if (@_) {
 		$self->{db} = shift;
 		if (exists $self->{db_connection}) {
-			$self->{db_connection} = open_db_connection($self->{db});
+			my $db = open_db_connection($self->{db});
+			$self->{db_connection} = $db if $db;
 		}
 	}
 	return $self->{db};
@@ -994,12 +1022,18 @@ sub metadata {
 	if ($key and $value) { 
 		# we are setting a new value
 		$self->{$index}{$key} = $value;
-		return 1;
+		return $value;
 	}
 	elsif ($key and not defined $value) {
-		# retrieve a value
-		return unless exists $self->{$index}{$key};
-		return $self->{$index}{$key};
+		if (exists $self->{$index}{$key}) {
+			# retrieve a value
+			return $self->{$index}{$key};
+		}
+		else {
+			# set a new empty key
+			$self->{$index}{$key} = q();
+			return 1;
+		}
 	}
 	else {
 		my %hash = %{ $self->{$index} };
@@ -1007,6 +1041,23 @@ sub metadata {
 	}
 }
 
+sub delete_metadata {
+	my $self = shift;
+	my ($index, $key) = @_;
+	return unless defined $index;
+	if (defined $key and exists $self->{$index}{$key}) {
+		return delete $self->{$index}{$key};
+	}
+	else {
+		# user wants to delete the metadata
+		# but we need to keep the basics name and index
+		foreach my $key (keys %{ $self->{$index} }) {
+			next if $key eq 'name';
+			next if $key eq 'index';
+			delete $self->{$index}{$key};
+		}
+	}
+}
 
 
 
