@@ -1,4 +1,4 @@
-#!/usr/bin/env perl
+#!/usr/bin/perl
 
 # documentation at end of file
 
@@ -25,7 +25,7 @@ eval {
 	require Parallel::ForkManager;
 	$parallel = 1;
 };
-my $VERSION = '1.14';
+my $VERSION = '1.15';
 
 print "\n This program will calculate observed & expected CpGs\n\n";
 
@@ -213,7 +213,8 @@ sub parallel_execution {
 		splice_data_structure($data, $i, $cpu);
 		
 		# re-open database objects to make them clone safe
-		$db = open_db_connection($database);
+		# pass second true to avoid cached database objects
+		$db = open_db_connection($database, 1);
 		
 		# Collect the data
 		process_regions();
@@ -458,22 +459,22 @@ The command line flags and descriptions:
 =item --db <name|file|directory>
 
 Provide the name of a Bio::DB::SeqFeature::Store database from which to 
-collect the genomic sequence. A relational database name, SQLite file, or 
-GFF3 file with sequence may be provided. Alternatively, provide the name 
+collect the genomic sequence. Alternatively, provide the name 
 of an uncompressed Fasta file (multi-fasta is ok) or directory containing 
 multiple fasta files representing the genomic sequence. The directory 
-must be writeable for a small index file to be written. 
-
+must be writeable for a small index file to be written. For more information 
+about using databases, see 
+L<https://code.google.com/p/biotoolbox/wiki/WorkingWithDatabases>. 
 The database may be provided in the metadata of an input file.
 
 =item --in <filename>
 
-Optionally specify an input file representing a list of regions to 
-analyze. If not provided, then the entire genome will be scanned using 
-the specified window size. Supported formats include BED, GFF, and tab 
-delimited text files with column headers (chromosome, start, and stop
-columns must be present and labeled as such or similarly). The file may 
-be compressed with gzip.
+Optionally specify an input file containing either a list of database features 
+or genomic coordinates for which to collect data. The file should be a 
+tab-delimited text file, one row per feature, with columns representing 
+feature identifiers, attributes, coordinates, and/or data values. The 
+first row should be column headers. Text files generated by other 
+B<BioToolBox> scripts are acceptable. Files may be gzipped compressed.
 
 =item --win <integer>
 
