@@ -1,4 +1,4 @@
-#!/usr/bin/env perl
+#!/usr/bin/perl
 
 # documentation at end of file
 
@@ -22,7 +22,7 @@ use Bio::ToolBox::file_helper qw(
 	load_tim_data_file
 	write_tim_data_file
 );
-my $VERSION = '1.14';
+my $VERSION = '1.15';
 
 
 print "\n A script to pull out overlapping features\n\n";
@@ -833,16 +833,23 @@ The command line flags and descriptions:
 
 =item --in <filename>
 
-Specify the file name of a list of reference features to find overlapping 
-target features. These reference features may be genomic coordinates (chromo,
-start, stop) or named features (name, type). A tim data formatted file is 
-best used but other tab delimited text formats may be used.
+Specify an input file containing either a list of database features or 
+genomic coordinates for which to collect data. The file should be a 
+tab-delimited text file, one row per feature, with columns representing 
+feature identifiers, attributes, coordinates, and/or data values. The 
+first row should be column headers. Bed files are acceptable, as are 
+text files generated by other B<BioToolBox> scripts. Files may be 
+gzipped compressed.
 
 =item --db <database>
 
-Provide the name of a Bio::DB::SeqFeature store database to use when 
-finding features. If not specified, the database specified in the input file 
-metadata will be used.
+Specify the name of a C<Bio::DB::SeqFeature::Store> annotation database 
+from which gene or feature annotation may be derived. A database is 
+required for generating new data files with features. This option may 
+skipped when using coordinate information from an input file (e.g. BED 
+file), or when using an existing input file with the database indicated 
+in the metadata. For more information about using annotation databases, 
+see L<https://code.google.com/p/biotoolbox/wiki/WorkingWithDatabases>. 
 
 =item --feature <text>
 
